<?php

/**************
 *   CLASS
 **************/

class easyFancyBox_Advanced {

	static $store_url = 'https://efbpro.firelightwp.com/';

	static $item_id = '3577';

	public static $compat_min = '1.9.1';

	public static $events = array( 'draw.dt', 'gform_post_render', 'facetwp-loaded' );

	private static $license_screen_id;

	private static $plugin_file;

	function __construct( $_plugin_file )
	{
		self::$plugin_file = $_plugin_file;

		/* HOOKS */
		add_action( 'init', array( __CLASS__, 'init' ), 11 );
		add_action( 'admin_init', array( __CLASS__, 'check_main_plugin' ) );

		// License & update.
		add_action( 'init', array( __CLASS__, 'plugin_updater' ), 0 );
		add_filter( 'auto_update_plugin', array( __CLASS__, 'disable_beta_autoupdates' ), 10, 2 );
		add_action( 'fancybox_check_license', array( __CLASS__, 'check_license' ) );

		// Settings.
		add_action( 'admin_init', array( __CLASS__, 'register_settings' ) );
		add_action( 'admin_menu', array( __CLASS__, 'register_license_page' ) );

		// Notices.
		add_action( 'current_screen', array( __CLASS__, 'license_admin_nag' ) );
		add_action( 'admin_notices', array( __CLASS__, 'admin_notices_action' ) );
		add_filter( 'plugin_action_links_'.plugin_basename( self::$plugin_file ), array( __CLASS__, 'add_action_link' ) );
		add_filter( 'plugin_row_meta', array( __CLASS__, 'plugin_meta_links' ), 10, 2);

		/* FILTERS */
		add_filter( 'easy_fancybox_onready_auto', array( __CLASS__, 'onready_auto_callback' ) );
		add_filter( 'easy_fancybox_inline_script', array( __CLASS__, 'filter_inline_script' ), 11 );
		add_filter( 'easy_fancybox_fb_opts', array( __CLASS__, 'filter_fb_opts' ) );
		add_filter( 'easy_fancybox_add_media', array( __CLASS__, 'filter_add_media' ) );
	}

	public static function init()
	{
		if ( ! class_exists( 'easyFancyBox' ) ) return;

		include dirname( self::$plugin_file ) . '/inc/easyfancybox-advanced-options.php';

		easyFancyBox::$options = self::array_merge_recursive_simple( easyFancyBox::$options, $advanced );

		if ( property_exists( 'easyFancyBox', 'events' ) ) {
			easyFancyBox::$events = array_merge( easyFancyBox::$events, self::$events );
		}
	}

	/*
	 * Custom array_merge made recursive.
	 *
	 * Slightly adapted version of custom array_merge_recursive function
	 * on http://www.php.net/manual/en/function.array-merge-recursive.php#104145
	 *
	 * @since
	 */
	private static function array_merge_recursive_simple()
	{
		if ( func_num_args() < 2 ) {
			trigger_error( __FUNCTION__ . ' needs two or more array arguments', E_USER_WARNING );
			return;
		}

		$arrays = func_get_args();
		$merged = array();
		while ( $arrays ) {
			$array = array_shift( $arrays );
			if ( ! is_array( $array ) ) {
				trigger_error( __FUNCTION__ . ' encountered a non array argument', E_USER_WARNING );
				return;
			}
			if ( ! $array ) {
				continue;
			}
			foreach ( $array as $key => $value ) {
				if ( is_array( $value ) && array_key_exists( $key, $merged ) && is_array( $merged[$key] ) ) {
					$merged[$key] = call_user_func( array( __CLASS__, __FUNCTION__ ), $merged[$key], $value );
				} else {
					$merged[$key] = $value;
				}
			}
		}

		return $merged;
	}

	public static function onready_auto_callback( $content )
	{
		$expires = get_option( 'fancybox_jqCookie' );

		if ( ! empty( $expires ) ) {
			$cookie = get_option( 'fancybox_cookiePath' ) ? 'fb_auto_"+window.location.pathname+"_'.$expires : 'fb_auto_'.$expires;

			// Replace onready_auto_callback.
			$content = 'jQuery(document).ready(function(){if(document.cookie.indexOf("'.$cookie.'=done")<0){easy_fancybox_auto();const d=new Date();d.setTime(d.getTime()+(3600000*'.$expires.'*24));document.cookie="'.$cookie.'=done;expires="+d.toUTCString()+";path=/";}});';
		}

		return $content;
	}

	public static function filter_fb_opts( $opts )
	{
		if ( \get_option( 'fancybox_enableVideoPress' ) ) {
			if ( ! isset( $opts['helpers']['media'] ) ) {
				$opts['helpers']['media'] = array();
			}
			$opts['helpers']['media']['videopress'] =  array(
				'matcher' => '{{videoPressMatcher}}', // >> /video(?:.word)press\.com\/(?:v\/|embed\/)(.*)/i
				'params'  => array(
					'hd'       => 1,
					'cover'    => 1,
					'autoPlay' => 1
				),
				'type'    => 'iframe',
				'url'     => '//videopress.com/embed/$1'
			);
		}

		return $opts;
	}

	public static function filter_add_media( $add_media )
	{
		if ( \get_option( 'fancybox_enableVideoPress' ) ) {
			return true;
		}

		return $add_media;
	}

	public static function filter_inline_style( $styles )
	{
		return $styles;
	}

	public static function filter_inline_script( $script )
	{
		// Replace fb2 VideoPress media helper matcher regex shortcode.
		if ( get_option( 'fancybox_enableVideoPress' ) ) {
			$script = str_replace( '"{{videoPressMatcher}}"', "/video(?:.word)press\.com\/(?:v\/|embed\/)(.*)/i", $script );
		}

		// Show/hide title on mouse hover.
		if ( get_option( 'fancybox_onStart' ) ) {
			// Add new listener.
			if ( 'fancyBox2' === get_option( 'fancybox_scriptVersion' ) ) {
				$script .= 'jQuery(document).on("onReady",function(){jQuery(".fancybox-skin").hover(function(){jQuery(".fancybox-title.fancybox-title-over-wrap").show();},function(){jQuery(".fancybox-title.fancybox-title-over-wrap").hide();});});' . PHP_EOL;
				$script .= 'jQuery(document).on("afterClose",function(){jQuery(".fancybox-skin").off("mouseenter mouseleave");});' . PHP_EOL;
			} else {
				$script .= 'jQuery(document).on("fancybox-start",function(){jQuery("#fancybox-wrap").hover(function(){jQuery("#fancybox-title-wrap.fancybox-title-over #fancybox-title").show();},function(){jQuery("#fancybox-title-wrap.fancybox-title-over #fancybox-title").hide();});});' . PHP_EOL;
				$script .= 'jQuery(document).on("fancybox-closed",function(){jQuery("#fancybox-wrap").off("mouseenter mouseleave");});' . PHP_EOL;
			}
		}

		// Replace AutoPlay shortcode.
		if ( get_option( 'fancybox_autoPlay' ) && 'fancyBox2' !== get_option( 'fancybox_scriptVersion' ) ) {
			$speed = get_option( 'fancybox_playSpeed' );
			if ( empty( $speed ) ) { $speed = '3000'; }

			$script .= 'jQuery(document).on("fancybox-start",function(){window.clearTimeout(fb_timeout);fb_timeout=window.setTimeout(function(){jQuery.fancybox.next();},'.$speed.');});' . PHP_EOL;
			$script .= 'jQuery(document).on("fancybox-closed",function(){window.clearTimeout(fb_timeout);});' . PHP_EOL;

		}

		// Compatibility.
		if ( get_option( 'fancybox_vcMasonryCompat' ) ) {
			// Remove prettyPhoto scripts.
			add_action( 'wp_footer', function() {
				wp_dequeue_script( 'prettyphoto' );
				wp_deregister_script( 'prettyphoto' );
				wp_dequeue_style( 'prettyphoto' );
				wp_deregister_style( 'prettyphoto' );
			}, 9 );

			// Add new listener.
			$script .= 'jQuery(window).on("grid:items:added",easy_fancybox_handler);' . PHP_EOL;
		}

		return $script;
	}

	public static function check_main_plugin()
	{
		if ( ! current_user_can( 'install_plugins' ) ) return;

		if ( ! class_exists( 'easyFancyBox' ) ) {
			if ( file_exists( WP_PLUGIN_DIR . '/easy-fancybox/easy-fancybox.php' ) )
				add_action( 'admin_notices', array( __CLASS__, 'admin_notice_activate' ) );
			else
				add_action( 'admin_notices', array( __CLASS__, 'admin_notice_install' ) );
		} elseif ( ! defined( 'EASY_FANCYBOX_VERSION' ) || version_compare(EASY_FANCYBOX_VERSION, self::$compat_min, '<' ) ) {
			add_action( 'admin_notices', array( __CLASS__, 'admin_notice_upgrade' ) );
		}
	}

	public static function admin_notice_install()
	{
		global $pagenow;
		if ( ! in_array( $pagenow, array( 'options-media.php', 'plugins.php' ) ) ) {
			return;
		}

		add_thickbox();
		?>
		<div class="notice notice-error is-dismissible">
			<p>
				<?php printf( /* translators: %1$s: Premium Plugin name, %2$s Plugin name (linked) */ __( 'To use the %1$s advanced options, please install %2$s.', 'easy-fancybox' ), __( 'Easy FancyBox Pro', 'easy-fancybox' ), '<a href="' . esc_url( network_admin_url( 'plugin-install.php?tab=plugin-information&plugin=easy-fancybox&TB_iframe=true&width=600&height=550' ) ) . '" target="_blank" class="thickbox">'.__( 'Easy FancyBox', 'easy-fancybox' ).'</a>' ); ?>
			</p>
		</div>
		<?php
	}

	public static function admin_notice_activate()
	{
		global $pagenow;
		if ( ! in_array( $pagenow, array( 'options-media.php', 'plugins.php' ) ) ) {
			return;
		}

		?>
		<div class="notice notice-warning is-dismissible">
			<p>
				<?php printf( /* Translators: Premium Plugin name, Plugin name */ __( 'In order to use %1$s, please activate %2$s.', 'easy-fancybox' ), __( 'Easy FancyBox Pro', 'easy-fancybox' ), '<strong>'.__( 'Easy FancyBox', 'easy-fancybox' ).'</strong>' ); ?>
			</p>
		</div>
		<?php
	}

	public static function admin_notice_upgrade()
	{
		global $pagenow;
		if ( ! in_array( $pagenow, array( 'options-media.php', 'plugins.php' ) ) ) {
			return;
		}

		/* Version Nag */
		add_thickbox();
		?>
		<div class="notice notice-warning is-dismissible">
			<p><?php _e( 'Notice: The current Easy FancyBox plugin version is not fully compatible with your version of the Pro extension. Some advanced options may not be functional.', 'easy-fancybox' ); ?>
				<?php printf( /* Translators: Plugin name (linked), version number */ __( 'Please upgrade %1$s to version %2$s or later.', 'easy-fancybox' ), '<a href="' . esc_url( network_admin_url( 'plugin-install.php?tab=plugin-information&plugin=easy-fancybox&TB_iframe=true&width=600&height=550' ) ) . '" target="_blank" class="thickbox">'.__( 'Easy FancyBox', 'easy-fancybox' ).'</a>', self::$compat_min ); ?></p>
		</div>
		<?php
	}

	public static function register_license_page()
	{
		self::$license_screen_id = add_submenu_page(
			'options.php',
			__( 'Easy FancyBox Pro License', 'easy-fancybox' ),
			'',
			'manage_options',
			'easy-fancybox-license',
			array( __CLASS__, 'license_page' )
		);

		// Help tab TODO
		//add_action( 'load-'.self::$license_screen_id, array( __CLASS__, 'help_tab' ) );
	}

	/**
	 * Hook in and instantiate Updater.
	 *
	 * @since 1.8
	 *
	 * @uses class Status301_Plugin_Updater
	 *
	 * @return void
	 */
	public static function plugin_updater()
	{
		// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
		$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
		if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
			return;
		}

		// Retrieve license key.
		$data = (array) get_option( 'easy_fancybox_license', array() );

		// Setup the updater.
		if ( ! class_exists( 'Status301_Plugin_Updater' ) ) {
			include dirname( self::$plugin_file ) . '/inc/class.status301-plugin-updater.php';
		}

		new Status301_Plugin_Updater(
			self::$store_url,
			self::$plugin_file,
			array(
				'version' => EASY_FANCYBOX_PRO_VERSION, // current version number
				'license' => isset( $data['key'] ) ? trim( $data['key'] ) : '', // license key (used get_option above to retrieve from DB)
				'item_id' => self::$item_id, // ID of the product
				'author'  => 'edanzer', // author of this plugin
				'beta'    => ! empty( $data['beta'] ),
			)
		);
	}

	/**
	 * Check and update license data.
	 *
	 * Hooked into fancybox_check_license event action.
	 *
	 * @since 1.8.5
	 *
	 * @uses class Status301_License_Manager
	 *
	 * @return void
	 */
	public static function check_license()
	{
		$data = (array) get_option( 'easy_fancybox_license', array() );

		$key = isset( $data['key'] ) ? $data['key'] : '';

		// Instantiate.
		if ( ! class_exists( 'Status301_License_Manager' ) ) {
			include dirname( self::$plugin_file ) . '/inc/class.status301-license-manager.php';
		}
		$license = new Status301_License_Manager( $key, self::$store_url, self::$item_id );

		// Check.
		$response = $license->check();

		// Update data only if we got a true or false response.
		if ( is_bool( $response ) ) {
			$data['status'] = $license->status;
			$data['expires'] = $license->expires;
			$data['error'] = $license->error;
			$data['payment_id'] = $license->payment_id;

			update_option( 'easy_fancybox_license', $data );
		}

		// Schedule a new license check in one month.
		if ( ! wp_next_scheduled( 'fancybox_check_license' ) ) {
			wp_schedule_single_event( time() + MONTH_IN_SECONDS, 'fancybox_check_license' );
		}

	}

	/**
	 * Prevent auto-updates for non-stable versions.
	 *
	 * @since 1.8.4
	 *
	 * @uses plugin_basename
	 *
	 * @return bool|null
	 */

	public static function disable_beta_autoupdates( $update, $plugin )
	{
		if ( plugin_basename( self::$plugin_file ) === $plugin->plugin ) {
			$stable_version = property_exists( $plugin, 'stable_version' ) ? $plugin->stable_version : $plugin->new_version;

			if ( $plugin->new_version !== $stable_version ) {
				return null;
			}
		}

		return $update;
	}

	/**
	* Adds an action link to the Plugins page
	*/
	public static function add_action_link( $links )
	{
		$settings_link = '<a href="' . admin_url( 'options.php' ) . '?page=easy-fancybox-license">' . __( 'License', 'easy-fancybox' ) . '</a>';
		array_unshift( $links, $settings_link );
		return $links;
	}

	/**
	* Adds links to plugin's description
	*/
	public static function plugin_meta_links( $links, $file )
	{
	  $support_link = '<a target="_blank" href="https://firelightwp.com/contact/">' . __( 'Support', 'easy-fancybox' ) . '</a>';

	  if ( $file == plugin_basename(self::$plugin_file) ) {
		$links[] = $support_link;
	  }

	  return $links;
	}

	/**
	* Returns messages for license error stati
	* @since 1.8
	*/
	public static function license_error_msg( $error, $expires = '' )
	{
		switch ( $error ) {
			case 'expired':
				if ( ! empty( $expires ) ) {
					return sprintf( /* Translators: Expiration date */ __( 'Your license key has expired on %s.', 'easy-fancybox' ), date_i18n( get_option( 'date_format' ), strtotime( $expires, current_time( 'timestamp' ) ) ) );
				} else {
					return __( 'Your license key has expired.', 'easy-fancybox' );
				}

			case 'disabled':
			case 'revoked':
				return __( 'Your license key has been disabled.', 'easy-fancybox' );

			case 'missing':
			case 'invalid':
				return __( 'This appears to be an invalid license key.', 'easy-fancybox' );

			case 'deactivated':
			case 'inactive':
			case 'site_inactive':
				return __( 'Your license is not active for this site.', 'easy-fancybox' );

			case 'invalid_item_id':
			case 'item_name_mismatch':
				return sprintf( /* Translators: Plugin name */ __( 'This appears to be an invalid license key for %s.', 'easy-fancybox' ), __( 'Easy FancyBox Pro', 'easy-fancybox' ) );

			case 'no_activations_left':
				return __( 'Your license key has reached its activation limit.', 'easy-fancybox' );

			case 'error':
				return __( 'An error occurred, please try again.', 'easy-fancybox' );

			case '':
				return __( 'An unkown error occurred. Please try again.', 'easy-fancybox' );

			default:
				return sprintf( /* Translators: license error code, Support (linked) */ __( 'Unexpected license error code %1$s. Please try again or get %2$s.', 'easy-fancybox' ), '<code>' . $error . '</code>', '<a target="_blank" href="https://firelightwp.com/contact/">' . __( 'Support', 'easy-fancybox' ) . '</a>' );
		}
	}

	/**
	* Displays all messages registered to 'your-settings-error-slug'
	*/
	public static function admin_notices_action()
	{
		settings_errors( 'easy_fancybox_license' );
	}

	/**
	* Check license validity and set nag
	*/
	public static function license_admin_nag()
	{
		// don't set these messages on license page itself or when saving options
		$screen = get_current_screen();
		if ( 'options' == $screen->id || self::$license_screen_id == $screen->id ) return;

		// retrieve our license key from the DB
		$option = (array) get_option( 'easy_fancybox_license', array() );

		if ( empty( $option['key'] ) ) {
			add_action( 'admin_notices',
				function() {
					echo '<div class="notice notice-error fade is-dismissible"><p>';
					printf( /* Translators: Plugin name */
						__( 'You have not yet entered your license key for %s.', 'easy-fancybox' ),
						__( 'Easy FancyBox Pro', 'easy-fancybox' )
					);
					echo ' ';
					printf( /* Translators: plugin admin page URL */
						__( 'To receive plugin updates, please <a href="%s">correct this issue</a>.', 'easy-fancybox' ),
						admin_url( 'options.php' ) . '?page=easy-fancybox-license'
					);
					echo '</p></div>';
				}
			);
		} else {
			switch( isset( $option['status'] ) ? $option['status'] : '' ) {
				case 'expired':
				case 'invalid':
					add_action( 'admin_notices',
						function() {
							echo '<div class="notice notice-error fade is-dismissible"><p>';
							printf( /* Translators: Plugin name */
								__( 'You have an invalid or expired license key for %s.', 'easy-fancybox' ),
								__( 'Easy FancyBox Pro', 'easy-fancybox' )
							);
							echo ' ';
							printf( /* Translators: plugin admin page URL */
								__( 'To receive plugin updates, please <a href="%s">correct this issue</a>.', 'easy-fancybox' ),
								admin_url( 'options.php' ) . '?page=easy-fancybox-license'
							);
							echo '</p></div>';
						}
					);
					break;
				case 'inactive':
					add_action( 'admin_notices',
						function() {
							echo '<div class="notice notice-warning fade is-dismissible"><p>';
							printf( /* Translators: Plugin name */
								__( 'Your license key for %s is not activated for this site.', 'easy-fancybox' ),
								__( 'Easy FancyBox Pro', 'easy-fancybox' )
							);
							echo ' ';
							printf( /* Translators: plugin admin page URL */
								__( 'To receive plugin updates, please <a href="%s">correct this issue</a>.', 'easy-fancybox' ),
								admin_url( 'options.php' ) . '?page=easy-fancybox-license'
							);
							echo '</p></div>';
						}
					);
					break;
				default:
					// no warning
			}
		}
	}

	/**
	* Register settings
	*/
	public static function register_settings()
	{
		// creates our settings in the options table
		register_setting( 'easy_fancybox_license', 'easy_fancybox_license', array( __CLASS__, 'sanitize_license' ) );
	}

	/**
	* License settings santize callback
	*/
	public static function sanitize_license( $new )
	{
		// Prevent double calls to this callback, still happens with object caching somehow.
		if ( ! isset( $new['action'] ) ) {
			return $new;
		}

		// Sanitize the options: license key, beta channel option.
		$sanitized = array(
			'key'  => ! empty( $new['key'] ) ? sanitize_text_field( $new['key'] ) : '',
			'beta' => ! empty( $new['beta'] )
		);

		// Short-circuit if there is no license key.
		if ( empty( $sanitized['key'] ) ) {
			return $sanitized;
		}

		$old = (array) get_option( 'easy_fancybox_license', array() );

		if ( ! empty( $old['key'] ) && $old['key'] === $sanitized['key'] ) {
			$sanitized['status'] = ! empty( $old['status'] ) ? $old['status'] : '';
			$sanitized['expires'] = ! empty( $old['expires'] ) ? $old['expires'] : '';
			$sanitized['error'] = ! empty( $old['error'] ) ? $old['error'] : '';
			$sanitized['payment_id'] = ! empty( $old['payment_id'] ) ? $old['payment_id'] : '';
		}

		// Include license manager class.
		if ( ! class_exists( 'Status301_License_Manager' ) ) {
			include dirname( self::$plugin_file ) . '/inc/class.status301-license-manager.php';
		}

		// instantiate
		$license = new Status301_License_Manager( $sanitized['key'], self::$store_url, self::$item_id );

		switch ( $new['action'] ) {
			case 'activate':
				// Activate license.
				$response = $license->activate();
				// Create admin message.
				if ( true === $response ) {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Your license was successfully activated for this site.', 'easy-fancybox' ), 'notice-success' );
				}
				break;

			case 'deactivate':
				// Deactivate license.
				$response = $license->deactivate();
				// Create admin message.
				if ( true === $response ) {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Your license was successfully deactivated for this site.', 'easy-fancybox' ), 'notice-info' );
				}
				break;

			default:
				// Check license.
				$response = $license->check();
				// Create admin message.
				if ( true === $response ) {
					if ( 'valid' == $license->status ) {
						add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Your license is active for this site.', 'easy-fancybox' ), 'notice-success' );
					} elseif ( 'inactive' == $license->status ) {
						add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Your license is not active for this site.', 'easy-fancybox' ), 'notice-info' );
					} else {
						add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', self::license_error_msg( $license->error, $license->expires ), 'notice-warning' );
					}
				}
		}

		switch ( true ) {
			case true === $response:
				// Update valid response data.
				$sanitized['status'] = $license->status;
				$sanitized['expires'] = $license->expires;
				$sanitized['error'] = $license->error;
				$sanitized['payment_id'] = $license->payment_id;
				break;

			case is_wp_error( $response ):
				add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', $response->get_error_message(), 'notice-error' );
				break;

			case is_numeric( $response ):
				if ( 492 == $response ) {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Too many requests. Please try again in a minute.', 'easy-fancybox' ), 'notice-error' );
				} elseif ( 999 == $response ) {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Cannot make requests to own domain.', 'easy-fancybox' ), 'notice-error' );
				} elseif ( 1000 == $response ) {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', __( 'Failed identify the product.', 'easy-fancybox' ), 'notice-error' );
				} else {
					add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', sprintf( /* Translators: http repsonse code */ __( 'Unexpected response code %d.', 'easy-fancybox' ), '<code>' . $response . '</code>' ), 'notice-error' );
				}
				break;

			default:
				add_settings_error( 'easy_fancybox_license', 'easy_fancybox_license_notice', self::license_error_msg( $license->error, $license->expires ), 'notice-error' );
		}

		// Schedule a new license check in one month.
		if ( ! wp_next_scheduled( 'fancybox_check_license' ) ) {
			wp_schedule_single_event( time() + MONTH_IN_SECONDS, 'fancybox_check_license' );
		}

		return $sanitized;
	}

	public static function license_page()
	{
		$data = (array) get_option( 'easy_fancybox_license', array() );

		$key = isset( $data['key'] ) ? $data['key'] : '';

		$status = isset( $data['status'] ) ? $data['status'] : '';
		$expires = isset( $data['expires'] ) && 'lifetime' !== $data['expires'] ? date_i18n( get_option( 'date_format' ), strtotime( $data['expires'], current_time( 'timestamp' ) ) ) : '';
		$payment_path = ! empty( $data['payment_id'] ) ? '?action=manage_licenses&payment_id=' . $data['payment_id'] : 'purchase-history/';
		$error = isset( $data['error'] ) ? $data['error'] : '';
		$beta = isset( $data['beta'] ) ? $data['beta'] : '';

		include dirname( self::$plugin_file ) . '/views/admin.php';
	}

}
