<?php
/**
 * EASY_FANCYBOX_MS_UNINSTALL
 *
 * Set this constant in wp-config.php if you want to allow looping over each site
 * in the network to run XMLSitemapFeed_Uninstall->uninstall() defined in uninstall.php
 *
 * There is NO batch-processing so it does not scale on large networks.
 * The constant is ignored on networks over 10k sites.
 *
 * example:
 * define( 'EASY_FANCYBOX_MS_UNINSTALL', true);
 */

// Exit if uninstall not called from WordPress.
defined( 'WP_UNINSTALL_PLUGIN' ) || exit();

/*
 * Easy FancyBox Pro uninstallation.
 *
 * @since 1.9
 */
class easyFancyBox_Uninstall {

	/*
	 * constructor: manages uninstall for multisite
	 *
	 * @since 1.9
	 */
	function __construct()
	{
		global $wpdb;

		// Check if it is a multisite and if EASY_FANCYBOX_MS_UNINSTALL constant is defined and
		// if so, run the uninstall function for each blog id.
		if ( is_multisite() && defined( 'EASY_FANCYBOX_MS_UNINSTALL' ) && EASY_FANCYBOX_MS_UNINSTALL && ! wp_is_large_network() ) {
			error_log( 'Clearing Easy FancyBox Pro settings from each site before uninstall:' );
			$field = 'blog_id';
			$table = $wpdb->prefix.'blogs';
			foreach ( $wpdb->get_col("SELECT {$field} FROM {$table}") as $blog_id ) {
				switch_to_blog($blog_id);
				$this->uninstall($blog_id);
			}
			restore_current_blog();
		} else {
			$this->uninstall();
		}
	}

	/**
	 * Remove plugin settings.
	 *
	 * @since 1.9
	 */
	function uninstall( $blog_id = false )
	{
		delete_option( 'easy_fancybox_pro_version' );
		delete_option( 'fancybox_license' );

		delete_option( 'fancybox_cookiePath' );
		delete_option( 'fancybox_jqCookie' );
		delete_option( 'fancybox_jQueryDeferred' );

		//delete_option( 'fancybox_onComplete' );
		delete_option( 'fancybox_onStart' );

		delete_option( 'fancybox_autoAttributeVideoPress' );
		delete_option( 'fancybox_enableVideoPress' );
		delete_option( 'fancybox_VideoPressHeight' );
		delete_option( 'fancybox_VideoPresspadding' );
		delete_option( 'fancybox_VideoPresstitleFromAlt' );
		delete_option( 'fancybox_VideoPresstitlePosition' );
		delete_option( 'fancybox_VideoPresstitleShow' );
		delete_option( 'fancybox_VideoPressWidth' );

		// Kilroy was here.
		if ( defined( 'WP_DEBUG' ) && WP_DEBUG ) {
			if ($blog_id)
				error_log( $blog_id );
			else
				error_log( 'Easy FancyBox Pro settings cleared on uninstall.' );
		}
	}
}

new easyFancyBox_Uninstall();
